@@ -1,10 +1,11 @@
 from django.db import models
 from django.db.models import Q
-from django.contrib.auth.models import UserManager
-from django.contrib.auth.models import User, AnonymousUser
+from django.contrib.auth.models import User, UserManager, Permission, AnonymousUser
+from django.contrib.contenttypes.models import ContentType
 
 from userena import settings as userena_settings
 from userena.utils import generate_sha1, get_profile_model
+from userena import signals as userena_signals
 
 from guardian.shortcuts import assign, get_perms
 
@@ -12,17 +13,37 @@ import re, datetime
 
 SHA1_RE = re.compile('^[a-f0-9]{40}$')
 
-PERMISSIONS = {
-    'profile': ('view_profile', 'change_profile'),
-    'user': ('change_user', 'delete_user')
+ASSIGNED_PERMISSIONS = {
+    'profile':
+        (('view_profile', 'Can view profile'),
+         ('change_profile', 'Can change profile')),
+    'user':
+        (('change_user', 'Can change user'),
+         ('delete_user', 'Can delete user'))
 }
 
 class UserenaManager(UserManager):
     """ Extra functionality for the Userena model. """
 
-    def create_inactive_user(self, username, email, password):
+    def create_inactive_user(self, username, email, password, send_email=True):
         """
-        A simple wrapper that creates a new ``User``.
+        A simple wrapper that creates a new :class:`User`.
+
+        :param username:
+            String containing the username of the new user.
+
+        :param email:
+            String containing the email address of the new user.
+
+        :param password:
+            String containing the password for the new user.
+
+        :param send_email:
+            Boolean that defines if the user should be send an email. You could
+            set this to ``False`` when you want to create a user in your own
+            code, but don't want the user to activate through email.
+
+        :return: :class:`User` instance representing the new user.
 
         """
         now = datetime.datetime.now()
@@ -35,23 +56,39 @@ class UserenaManager(UserManager):
 
         # All users have an empty profile
         profile_model = get_profile_model()
-        new_profile = profile_model(user=new_user)
-        new_profile.save(using=self._db)
+        try:
+            profile = new_user.get_profile()
+        except profile_model.DoesNotExist:
+            new_profile = profile_model(user=new_user)
+            new_profile.save(using=self._db)
 
         # Give permissions to view and change profile
-        for perm in PERMISSIONS['profile']:
-            assign(perm, new_user, new_profile)
+        for perm in ASSIGNED_PERMISSIONS['profile']:
+            assign(perm[0], new_user, new_profile)
 
         # Give permissinos to view and change itself
-        for perm in PERMISSIONS['user']:
-            assign(perm, new_user, new_user)
+        for perm in ASSIGNED_PERMISSIONS['user']:
+            assign(perm[0], new_user, new_user)
 
-        userena_profile.send_activation_email()
+        if send_email:
+            userena_profile.send_activation_email()
+
+        # Send the signup complete signal
+        userena_signals.signup_complete.send(sender=None,
+                                             user=new_user)
 
         return new_user
 
     def create_userena_profile(self, user):
-        """ Creates an userena profile """
+        """
+        Creates an :class:`UserenaSignup` instance for this user.
+
+        :param user:
+            Django :class:`User` instance.
+
+        :return: The newly created :class:`UserenaSignup` instance.
+
+        """
         if isinstance(user.username, unicode):
             user.username = user.username.encode('utf-8')
         salt, activation_key = generate_sha1(user.username)
@@ -61,10 +98,19 @@ class UserenaManager(UserManager):
 
     def activate_user(self, username, activation_key):
         """
-        Activate an ``User`` by supplying a valid ``activation_key``.
+        Activate an :class:`User` by supplying a valid ``activation_key``.
 
-        If the key is valid and an user is found, activate the user and
-        return it.
+        If the key is valid and an user is found, activates the user and
+        return it. Also sends the ``activation_complete`` signal.
+
+        :param username:
+            String containing the username that wants to be activated.
+
+        :param activation_key:
+            String containing the secret SHA1 for a valid activation.
+
+        :return:
+            The newly activated :class:`User` or ``False`` if not successful.
 
         """
         if SHA1_RE.search(activation_key):
@@ -79,6 +125,11 @@ class UserenaManager(UserManager):
                 user.is_active = True
                 userena.save(using=self._db)
                 user.save(using=self._db)
+
+                # Send the activation_complete signal
+                userena_signals.activation_complete.send(sender=None,
+                                                         user=user)
+
                 return user
         return False
 
@@ -90,6 +141,16 @@ class UserenaManager(UserManager):
         as the current e-mail address. Returns the user after success or
         ``False`` when the confirmation key is invalid.
 
+        :param username:
+            String containing the username of the user that wants their email
+            verified.
+
+        :param confirmation_key:
+            String containing the secret SHA1 that is used for verification.
+
+        :return:
+            The verified :class:`User` or ``False`` if not successful.
+
         """
         if SHA1_RE.search(confirmation_key):
             try:
@@ -104,6 +165,11 @@ class UserenaManager(UserManager):
                 userena.email_unconfirmed, userena.email_confirmation_key = '',''
                 userena.save(using=self._db)
                 user.save(using=self._db)
+
+                # Send the activation_complete signal
+                userena_signals.confirmation_complete.send(sender=None,
+                                                           user=user)
+
                 return user
         return False
 
@@ -112,7 +178,7 @@ class UserenaManager(UserManager):
         Checks for expired users and delete's the ``User`` associated with
         it. Skips if the user ``is_staff``.
 
-        Returns a list of the deleted users.
+        :return: A list containing the deleted users.
 
         """
         deleted_users = []
@@ -127,28 +193,43 @@ class UserenaManager(UserManager):
         """
         Checks that all permissions are set correctly for the users.
 
-        Returns a set of users whose permissions was wrong.
+        :return: A set of users whose permissions was wrong.
 
         """
+        # Check that all the permissions are available.
+        for model, perms in ASSIGNED_PERMISSIONS.items():
+            for perm in perms:
+                try:
+                    Permission.objects.get(codename=perm[0])
+                except Permission.DoesNotExist:
+                    if model == 'profile':
+                        model_obj = get_profile_model()
+                    else: model_obj = User
+                    content_type = ContentType.objects.get_for_model(model_obj)
+                    Permission.objects.create(name=perm[1],
+                                              codename=perm[0],
+                                              content_type=content_type)
+
+        # Check permission for every user.
         changed_users = set()
         for user in User.objects.all():
             if not user.username == 'AnonymousUser':
                 all_permissions = get_perms(user, user.get_profile()) + get_perms(user, user)
 
-                for model, perms in PERMISSIONS.items():
+                for model, perms in ASSIGNED_PERMISSIONS.items():
                     if model == 'profile':
                         perm_object = user.get_profile()
                     else: perm_object = user
 
                     for perm in perms:
-                        if perm not in all_permissions:
-                            assign(perm, user, perm_object)
+                        if perm[0] not in all_permissions:
+                            assign(perm[0], user, perm_object)
                             changed_users.add(user)
 
         return changed_users
 
 class UserenaBaseProfileManager(models.Manager):
-    """ Manager for UserenaProfile """
+    """ Manager for :class:`UserenaProfile` """
     def get_visible_profiles(self, user=None):
         """
         Returns all the visible profiles available to this user.
@@ -157,10 +238,11 @@ class UserenaBaseProfileManager(models.Manager):
         active, a user has it's profile closed to everyone or a user only
         allows registered users to view their profile.
 
-        **Keyword Arguments**
+        :param user:
+            A Django :class:`User` instance.
 
-        ``user``
-            A django ``User`` instance.
+        :return:
+            All profiles that are visible to this user.
 
         """
         profiles = self.all()
