@@ -11,7 +11,8 @@ from django.utils.translation import ugettext as _
 from django.views.generic import list_detail
 from django.http import HttpResponseForbidden, Http404
 
-from userena.forms import SignupForm, AuthenticationForm, ChangeEmailForm, EditProfileForm
+from userena.forms import (SignupForm, SignupFormOnlyEmail, AuthenticationForm,
+                           ChangeEmailForm, EditProfileForm)
 from userena.models import UserenaSignup
 from userena.decorators import secure_required
 from userena.backends import UserenaAuthenticationBackend
@@ -31,22 +32,20 @@ def signup(request, signup_form=SignupForm,
     an email with an activation link used to activate their account. After
     successful signup redirects to ``success_url``.
 
-    **Keyword arguments**
-
-    ``signup_form``
+    :param signup_form:
         Form that will be used to sign a user. Defaults to userena's
-        ``forms.SignupForm``.
+        :class:`SignupForm`.
 
-    ``template_name``
+    :param template_name:
         String containing the template name that will be used to display the
         signup form. Defaults to ``userena/signup_form.html``.
 
-    ``success_url``
+    :param success_url:
         String containing the URI which should be redirected to after a
         successfull signup. If not supplied will redirect to
         ``userena_signup_complete`` view.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary containing variables which are added to the template
         context. Defaults to a dictionary with a ``form`` key containing the
         ``signup_form``.
@@ -57,6 +56,11 @@ def signup(request, signup_form=SignupForm,
         Form supplied by ``signup_form``.
 
     """
+    # If no usernames are wanted and the default form is used, fallback to the
+    # default form that doesn't display to enter the username.
+    if userena_settings.USERENA_WITHOUT_USERNAMES and (signup_form == SignupForm):
+        signup_form = SignupFormOnlyEmail
+
     form = signup_form()
 
     if request.method == 'POST':
@@ -69,7 +73,8 @@ def signup(request, signup_form=SignupForm,
                                         kwargs={'username': user.username})
 
             # A new signed user should logout the old one.
-            logout(request)
+            if request.user.is_authenticated():
+                logout(request)
             return redirect(redirect_to)
 
     if not extra_context: extra_context = dict()
@@ -84,35 +89,31 @@ def activate(request, username, activation_key,
     """
     Activate a user with an activation key.
 
-    The key is a SHA1 string. When the SHA1 is found with an ``Account``, the
-    ``User`` of that account will be activated. After a successfull activation
-    the view will redirect to ``succes_url``.  If the SHA1 is not found, the
-    user will be shown the ``template_name`` template displaying a fail
-    message.
+    The key is a SHA1 string. When the SHA1 is found with an
+    :class:`UserenaSignup`, the :class:`User` of that account will be
+    activated.  After a successfull activation the view will redirect to
+    ``succes_url``.  If the SHA1 is not found, the user will be shown the
+    ``template_name`` template displaying a fail message.
 
-    **Arguments**
-
-    ``username``
+    :param username:
         String of the username that wants to be activated.
 
-    ``activation_key``
+    :param activation_key:
         String of a SHA1 string of 40 characters long. A SHA1 is always 160bit
         long, with 4 bits per character this makes it --160/4-- 40 characters
         long.
 
-    **Keyword arguments**
-
-    ``template_name``
+    :param template_name:
         String containing the template name that is used when the
         ``activation_key`` is invalid and the activation failes. Defaults to
         ``userena/activation_fail.html``.
 
-    ``success_url``
+    :param success_url:
         Named URL where the user should be redirected to after a succesfull
         activation. If not specified, will direct to
         ``userena_profile_detail`` view.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary containing variables which could be added to the template
         context. Default to an empty dictionary.
 
@@ -145,33 +146,29 @@ def email_confirm(request, username, confirmation_key,
     """
     Confirms an email address with a confirmation key.
 
-    Confirms a new email address by running ``User.objects.confirm_email``
-    method. If the method returns an ``User`` the user will have his new
+    Confirms a new email address by running :func:`User.objects.confirm_email`
+    method. If the method returns an :class:`User` the user will have his new
     e-mail address set and redirected to ``success_url``. If no ``User`` is
     returned the user will be represented with a fail message from
     ``template_name``.
 
-    **Arguments**
-
-    ``username``
+    :param username:
         String of the username whose email address needs to be confirmed.
 
-    ``confirmation_key``
+    :param confirmation_key:
         String with a SHA1 representing the confirmation key used to verify a
         new email address.
 
-    **Keyword arguments**
-
-    ``template_name``
+    :param template_name:
         String containing the template name which should be rendered when
         confirmation fails. When confirmation is succesfull, no template is
         needed because the user will be redirected to ``success_url``.
 
-    ``success_url``
+    :param success_url:
         Named URL which is redirected to after a succesfull confirmation.
         Supplied argument must be able to be rendered by ``reverse`` function.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary of variables that are passed on to the template supplied by
         ``template_name``.
 
@@ -191,19 +188,17 @@ def email_confirm(request, username, confirmation_key,
 def direct_to_user_template(request, username, template_name,
                             extra_context=None):
     """
-    Simple wrapper for Django's ``direct_to_template`` view.
+    Simple wrapper for Django's :func:`direct_to_template` view.
 
     This view is used when you want to show a template to a specific user. A
-    wrapper for ``direct_to_template`` where the template also has access to
+    wrapper for :func:`direct_to_template` where the template also has access to
     the user that is found with ``username``. For ex. used after signup,
     activation and confirmation of a new e-mail.
 
-    **Arguments**
-
-    ``username``
+    :param username:
         String defining the username of the user that made the action.
 
-    ``template_name``
+    :param template_name:
         String defining the name of the template to use. Defaults to
         ``userena/signup_complete.html``.
 
@@ -214,11 +209,16 @@ def direct_to_user_template(request, username, template_name,
         rendered template. The ``account`` key is always the ``User``
         that completed the action.
 
+    **Extra context**
+
+    ``viewed_user``
+        The currently :class:`User` that is viewed.
+
     """
     user = get_object_or_404(User, username__iexact=username)
 
     if not extra_context: extra_context = dict()
-    extra_context['account'] = user
+    extra_context['viewed_user'] = user
     return direct_to_template(request,
                               template_name,
                               extra_context=extra_context)
@@ -232,35 +232,33 @@ def signin(request, auth_form=AuthenticationForm,
     Signin using email or username with password.
 
     Signs a user in by combining email/username with password. If the
-    combination is correct and the user ``is_active`` the
-    ``redirect_signin_function`` is called with the arguments
-    ``REDIRECT_FIELD_NAME`` and an instance of the ``User`` whois is trying the
-    login. The returned value of the function will be the URL that is
-    redirected to.
+    combination is correct and the user :func:`is_active` the
+    :func:`redirect_signin_function` is called with the arguments
+    ``REDIRECT_FIELD_NAME`` and an instance of the :class:`User` whois is
+    trying the login. The returned value of the function will be the URL that
+    is redirected to.
 
     A user can also select to be remembered for ``USERENA_REMEMBER_DAYS``.
 
-    **Keyword arguments**
-
-    ``auth_form``
+    :param auth_form:
         Form to use for signing the user in. Defaults to the
-        ``AuthenticationForm`` supplied by userena.
+        :class:`AuthenticationForm` supplied by userena.
 
-    ``template_name``
+    :param template_name:
         String defining the name of the template to use. Defaults to
         ``userena/signin_form.html``.
 
-    ``redirect_field_name``
+    :param redirect_field_name:
         Form field name which contains the value for a redirect to the
         successing page. Defaults to ``next`` and is set in
         ``REDIRECT_FIELD_NAME`` setting.
 
-    ``redirect_signin_function``
+    :param redirect_signin_function:
         Function which handles the redirect. This functions gets the value of
-        ``REDIRECT_FIELD_NAME`` and the ``User`` who has logged in. It must
-        return a string which specifies the URI to redirect to.
+        ``REDIRECT_FIELD_NAME`` and the :class:`User` who has logged in. It
+        must return a string which specifies the URI to redirect to.
 
-    ``extra_context``
+    :param extra_context:
         A dictionary containing extra variables that should be passed to the
         rendered template. The ``form`` key is always the ``auth_form``.
 
@@ -272,9 +270,6 @@ def signin(request, auth_form=AuthenticationForm,
     """
     form = auth_form
 
-    # Sign a user out if he/she is at the signin page.
-    logout(request)
-
     if request.method == 'POST':
         form = auth_form(request.POST, request.FILES)
         if form.is_valid():
@@ -286,7 +281,7 @@ def signin(request, auth_form=AuthenticationForm,
             if user.is_active:
                 login(request, user)
                 if remember_me:
-                    request.session.set_expiry(userena_settings.USERENA_REMEMBER_ME_DAYS[1] * 3600)
+                    request.session.set_expiry(userena_settings.USERENA_REMEMBER_ME_DAYS[1] * 86400)
                 else: request.session.set_expiry(0)
 
                 if userena_settings.USERENA_USE_MESSAGES:
@@ -294,12 +289,8 @@ def signin(request, auth_form=AuthenticationForm,
                                      fail_silently=True)
 
                 # Whereto now?
-                requested_redirect = request.REQUEST.get(redirect_field_name, False)
-                if requested_redirect:
-                    redirect_to = requested_redirect
-                else:
-                    redirect_to = redirect_signin_function(requested_redirect,
-                                                           user)
+                redirect_to = redirect_signin_function(
+                    request.REQUEST.get(redirect_field_name), user)
                 return redirect(redirect_to)
             else:
                 return redirect(reverse('userena_disabled',
@@ -321,27 +312,23 @@ def email_change(request, username, form=ChangeEmailForm,
     """
     Change email address
 
-    **Arguments**
-
-    ``username``
+    :param username:
         String of the username which specifies the current account.
 
-    **Keyword arguments**
-
-    ``form``
+    :param form:
         Form that will be used to change the email address. Defaults to
-        ``ChangeEmailForm`` supplied by userena.
+        :class:`ChangeEmailForm` supplied by userena.
 
-    ``template_name``
+    :param template_name:
         String containing the template to be used to display the email form.
         Defaults to ``userena/email_form.html``.
 
-    ``success_url``
+    :param success_url:
         Named URL where the user will get redirected to when succesfully
         changing their email address.  When not suplied will redirect to
         ``userena_email_complete`` URL.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary containing extra variables that can be used to render the
         template. The ``form`` key is always the form supplied by the keyword
         argument ``form`` and the ``user`` key by the user whose email address
@@ -391,34 +378,31 @@ def password_change(request, username, template_name='userena/password_form.html
     """ Change password of user.
 
     This view is almost a mirror of the view supplied in
-    ``contrib.auth.views.password_change``, with the minor change that in this
-    view we also use the username to change the password. This was needed to
-    keep our URLs logical (and REST) accross the entire application. And that
-    in a later stadium administrators can also change the users password
+    :func:`contrib.auth.views.password_change`, with the minor change that in
+    this view we also use the username to change the password. This was needed
+    to keep our URLs logical (and REST) accross the entire application. And
+    that in a later stadium administrators can also change the users password
     through the web application itself.
 
-    **Arguments**
-
-    ``username``
 
+    :param username:
         String supplying the username of the user who's password is about to be
         changed.
 
-    **Keyword arguments**
-
-    ``template_name``
+    :param template_name:
         String of the name of the template that is used to display the password
         change form. Defaults to ``userena/password_form.html``.
 
-    ``pass_form``
+    :param pass_form:
         Form used to change password. Default is the form supplied by Django
         itself named ``PasswordChangeForm``.
 
-    ``success_url``
-        Named URL that is passed onto a ``reverse`` function with ``username``
-        of the active user. Defaults to the ``userena_password_complete`` URL.
+    :param success_url:
+        Named URL that is passed onto a :func:`reverse` function with
+        ``username`` of the active user. Defaults to the
+        ``userena_password_complete`` URL.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary of extra variables that are passed on the the template. The
         ``form`` key is always used by the form supplied by ``pass_form``.
 
@@ -427,9 +411,6 @@ def password_change(request, username, template_name='userena/password_form.html
     ``form``
         Form used to change the password.
 
-    ``account``
-        The current active account.
-
     """
     user = get_object_or_404(User,
                              username__iexact=username)
@@ -461,43 +442,41 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
     Edit profile.
 
     Edits a profile selected by the supplied username. First checks
-    permissions if the user is allowed to edit this account, if denied will
-    show a 404. When the account is succesfully edited will redirect to
+    permissions if the user is allowed to edit this profile, if denied will
+    show a 404. When the profile is succesfully edited will redirect to
     ``success_url``.
 
-    **Arguments**
+    :param username:
+        Username of the user which profile should be edited.
 
-    ``username``
-        Username of the user which account should be edited.
+    :param edit_profile_form:
 
-    **Keyword arguments**
+        Form that is used to edit the profile. The :func:`EditProfileForm.save`
+        method of this form will be called when the form
+        :func:`EditProfileForm.is_valid`.  Defaults to :class:`EditProfileForm`
+        from userena.
 
-    ``edit_profile_form``
-        Form that is used to edit the account. The ``save`` method of this form
-        will be called when the form ``is_valid``. Defaults to
-        ``AccountEditForm`` from userena.
+    :param template_name:
+        String of the template that is used to render this view. Defaults to
+        ``userena/edit_profile_form.html``.
 
-    ``template_name``
-        String of the template that is used to render the
-        ``edit_profile_form``.  Defaults to ``userena/edit_profile_form.html``.
-
-    ``success_url``
+    :param success_url:
         Named URL which be passed on to a django ``reverse`` function after the
         form is successfully saved. Defaults to the ``userena_detail`` url.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary containing variables that are passed on to the
         ``template_name`` template.  ``form`` key will always be the form used
-        to edit the account, and the ``account`` key is always the edited
-        account.
+        to edit the profile, and the ``profile`` key is always the edited
+        profile.
 
     **Context**
 
     ``form``
-        Form that is used to alter the account.
+        Form that is used to alter the profile.
 
-    ``account``
-        Instance of the ``Account`` that is edited.
+    ``profile``
+        Instance of the ``Profile`` that is edited.
 
     """
     user = get_object_or_404(User,
@@ -527,7 +506,7 @@ def profile_edit(request, username, edit_profile_form=EditProfileForm,
 
     if not extra_context: extra_context = dict()
     extra_context['form'] = form
-    extra_context['user'] = user
+    extra_context['profile'] = profile
     return direct_to_template(request,
                               template_name,
                               extra_context=extra_context)
@@ -536,25 +515,21 @@ def profile_detail(request, username, template_name='userena/profile_detail.html
     """
     Detailed view of an user.
 
-    **Arguments**
+    :param username:
+        String of the username of which the profile should be viewed.
 
-    ``username``
-        String of the username of which the account should be viewed.
-
-    **Keyword arguments**
-
-    ``template_name``
+    :param template_name:
         String representing the template name that should be used to display
-        the account.
+        the profile.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary of variables which should be supplied to the template. The
-        ``account`` key is always the current account.
+        ``profile`` key is always the current profile.
 
     **Context**
 
-    ``account``
-        Instance of the currently edited ``Account``.
+    ``profile``
+        Instance of the currently viewed ``Profile``.
 
     """
     user = get_object_or_404(User,
@@ -576,33 +551,31 @@ def profile_list(request, page=1, template_name='userena/profile_list.html',
     It's possible to disable this by changing ``USERENA_DISABLE_PROFILE_LIST``
     to ``True`` in your settings.
 
-    **Keyword arguments**
-
-    ``page``
+    :param page:
         Integer of the active page used for pagination. Defaults to the first
         page.
 
-    ``template_name``
+    :param template_name:
         String defining the name of the template that is used to render the
         list of all users. Defaults to ``userena/list.html``.
 
-    ``paginate_by``
-        Integer defining the amount of displayed accounts per page. Defaults to
-        50 accounts per page.
+    :param paginate_by:
+        Integer defining the amount of displayed profiles per page. Defaults to
+        50 profiles per page.
 
-    ``extra_context``
+    :param extra_context:
         Dictionary of variables that are passed on to the ``template_name``
         template.
 
     **Context**
 
-    ``account_list``
-        A list of accounts.
+    ``profile_list``
+        A list of profiles.
 
     ``is_paginated``
         A boolean representing whether the results are paginated.
 
-    If the result is paginated. It will also contain the following variables:
+    If the result is paginated. It will also contain the following variables.
 
     ``paginator``
         An instance of ``django.core.paginator.Paginator``.
@@ -613,7 +586,7 @@ def profile_list(request, page=1, template_name='userena/profile_list.html',
     """
     try:
         page = int(request.GET.get('page', None))
-    except TypeError, ValueError:
+    except (TypeError, ValueError):
         page = page
 
     if userena_settings.USERENA_DISABLE_PROFILE_LIST \
